Learn R Programming

SafeVote (version 1.0.2)

gisborne2022analysis: Analysis of results from the Gisborne 2022 election.

Description

Analysis of results from the Gisborne 2022 election.

Usage

gisborne2022analysis

Arguments

Format

a dataframe with a column labelled "closeness" -- which is easily calculated and might be a valid metric for the safety of the results of an STV election.