Ballots are deleted at random from the ballot-box, with election results
computed once per 'dinc' ballot-deletions. The experiment terminates after a
specified number of ballots have been deleted, or a specified number of
ballot-counts have occurred. Note: these ballot-counts are correlated. Use
testFraction() to experiment with independently-drawn samples from the
ballot-box.
testDeletions(
votes,
countMethod = "stv",
countArgs = list(),
dstart = NULL,
dinc = NULL,
dlimit = NULL,
drep = NULL,
rankMethod = "safeRank",
exptName = NULL,
equiet = FALSE,
everbose = FALSE
)'SafeRankExpt' object of experimental results. See
new_SafeRankExpt()
A set of ballots, as in vote_2.3.2
"stv" (default) or "condorcet"
List of args to be passed to 'countMethod' (in addition to 'votes')
Number of ballots in the first ballot-count (selected at random from 'votes', without replacement)
Number of ballots to be deleted in subsequent steps
Maximum number of ballots to delete (in addition to 'dstart')
Maximum number of elections (required if 'dinc=0')
"safeRank" (default), "elected", or "rank". "rank" is a total ranking of the candidates, with ties broken at random. "elected" assigns rank=1 to elected candidates, rank=2 to eliminated candidates.
stem-name of experimental units e.g. "E". If 'NULL', then a 3-character string of capital letters is chosen at random.
TRUE to suppress all experimental output
TRUE to produce diagnostic output from the experiment
testDeletions(food_election, countMethod="stv",
countArgs=list(complete.ranking=TRUE))
Run the code above in your browser using DataLab